@@ -206,7 +206,7 @@ class ResponseObject(object):
 	def __init__(self):
 		self.success = False
 		self.message = None
-		self.error = "*** ResponseObject is not initialized ***"
+		self.error = None
 	# iterate over self keys & variables.
 	def items(self):
 		return vars(self).items()
@@ -230,6 +230,9 @@ class ResponseObject(object):
 		setattr(self, key, value)
 	def __getitem__(self, key):
 		return getattr(self, key)
+	# string format.
+	def __str__(self):
+		return json.dumps(self.dict(), indent=4)
 
 # initialized objects.
 r3sponse = R3sponse()
